#
# PROGRAM: PYTHON CONSOLE DATABASE BROWSER
# MODULE : LIST TO STRING
#

def list_to_str(p_list):
  res=""
  row=""
  if p_list is None:
    return([])
  list_keys = list(p_list.keys())
  for k in list_keys:
    res+="|"+k
  res=res[1:]
  res+="\n"
  if len(p_list)==0:
    imax=0 
  else:
    imax = len(p_list[list_keys[0]])
  for i in range(0,imax):
    for k in list_keys:
      if len(p_list[k])>0:
        row+="|"+str(p_list[k][i]).replace('|',',')
    row=row[1:]+"\n"
    res+=row
    row=""
  res=res[:-1]
  return(res)



#
# PROGRAM: PYTHON CONSOLE DATABASE BROWSER
# MODULE : KEY PRESS PROCESSOR
#

def key_moves(
  he,         # screen height
  wi,         # screen width
  k,          # pressed keycode
  curx,       # current cell x coordinate
  cury,       # current cell y coordinate
  maxx,       # number of columns
  maxy,       # number of rows
  cur_win,    # current window [ left, right ]
  tabf,       # visible rows shift from
  tabt,       # visible rows shift number
  act,        # action
  curtabsf,   # left window visible records shift
  colshift=0  # right window columns shift
):
  act=""
  if k==ord("j"):
    if cury<maxy:
      cury+=1
  elif k==ord("J"):
    if tabf<maxy-1:
      tabf+=1
  elif k==ord("k"):
    if cury>1:
      cury-=1
  elif k==ord("K"):
    if tabf>0:
      tabf-=1
  elif k==ord("@"):
    tabf+=cury-1
    cury=1
  elif k==ord("h"):
    if curx>0:
      curx-=1
  elif k==ord("l"):
    if curx<maxx-colshift-1:
      curx+=1
  elif k==ord("L"):
    if colshift<maxx-curx-1:
      colshift+=1
  elif k==ord("H"):
    if colshift>0:
      colshift-=1
  elif k==ord("0"):
    curx=0
  elif k==ord("G"):
    if cur_win == "right":
      curx=maxx-1
      cury=maxy
  elif k==ord("n"):
    if maxy > he - 3:
      tabf+=maxy-1
  elif k==ord("u"):
    if tabf > he - 3:
      tabf -= maxy -1
    else:
      tabf = 0
  elif k==ord("s"):
    act="asc"
  elif k==ord("S"):
    act="desc"
  elif k==ord("f"):
    act="filter"
  elif k==ord("\t"):
    if cur_win == "left":
      cur_win = "right"
    elif cur_win == "right":
      cur_win = "left"
  elif k == ord("m"):
    if maxy > he - 3:
      curtabsf += he - 1
    else:
      cury = maxy
  elif k == ord("i"):
    if curtabsf >= he -1:
      curtabsf -= he - 1
    else:
      cury = 1
  elif k == ord("?"):
    act="help"
  elif k == ord("r"):
    act="refresh"
  elif k == ord("e"):
    act="edit_cell"
  elif k == ord("a"):
    act="insert_row"
  elif k == ord("d"):
    act="delete_row"
  elif k == ord("$"):
    act="conn_info"
  return(
    curx,
    cury,
    cur_win,
    tabf,
    tabt,
    act,
    curtabsf,
    colshift
  )



#
# PROGRAM: PYTHON CONSOLE DATABASE BROWSER
# MODULE : LOG
#

from datetime import datetime

DEBUG = 0

def msg_log(msg):
  dt = datetime.now()
  if DEBUG==1:
    f = open("/tmp/pydbro.log","a")
    f.write(str(dt)+" "+msg+"\n")
    f.close()



#
# PROGRAM: PYTHON CONSOLE DATABASE BROWSER
# MODULE : CURSES COLORS
#

import curses
import locale

cols = {}

def init_colors():
    global cols
    curses.start_color()
    curses.init_pair(1, curses.COLOR_CYAN, curses.COLOR_BLACK)
    curses.init_pair(2, curses.COLOR_RED, curses.COLOR_BLACK)
    curses.init_pair(3, curses.COLOR_GREEN, curses.COLOR_BLACK)
    curses.init_pair(4, curses.COLOR_BLUE, curses.COLOR_BLACK)
    curses.init_pair(5, curses.COLOR_WHITE, curses.COLOR_BLACK)
    cols["hiTe"] = curses.color_pair(1) | curses.A_BOLD
    cols["miTe"] = curses.color_pair(1)
    cols["loTe"] = curses.color_pair(1) | curses.A_DIM
    cols["hiRe"] = curses.color_pair(2) | curses.A_BOLD
    cols["miRe"] = curses.color_pair(2)
    cols["loRe"] = curses.color_pair(2) | curses.A_DIM
    cols["hiGr"] = curses.color_pair(3) | curses.A_BOLD
    cols["miGr"] = curses.color_pair(3)
    cols["loGr"] = curses.color_pair(3) | curses.A_DIM
    cols["hiBl"] = curses.color_pair(4) | curses.A_BOLD
    cols["miBl"] = curses.color_pair(4)
    cols["loBl"] = curses.color_pair(4) | curses.A_DIM
    cols["hiWh"] = curses.color_pair(5) | curses.A_BOLD
    cols["miWh"] = curses.color_pair(5)
    cols["loWh"] = curses.color_pair(5) | curses.A_DIM
    return cols
